@@ -185,8 +185,10 @@ xfce_panel_plugin_provider_emit_signal (XfcePanelPluginProvider       *provider,
 {
   panel_return_if_fail (XFCE_IS_PANEL_PLUGIN_PROVIDER (provider));
 
-  /* emit the signal */
-  g_signal_emit (G_OBJECT (provider), provider_signals[PROVIDER_SIGNAL], 0, provider_signal);
+  /* emit the signal only if the plugin has not already been unparented (see
+   * panel_itembar_unref()) */
+  if (gtk_widget_get_parent (GTK_WIDGET (provider)) != NULL)
+    g_signal_emit (provider, provider_signals[PROVIDER_SIGNAL], 0, provider_signal);
 }
 
 
