@@ -553,6 +553,9 @@ panel_application_plugin_move_drag_end (GtkWidget        *item,
   g_signal_handlers_disconnect_by_func (G_OBJECT (item),
       G_CALLBACK (panel_application_plugin_move_drag_data_get), application);
 
+  /* release extra reference */
+  g_object_unref (item);
+
   /* unblock autohide */
   panel_application_windows_blocked (application, FALSE);
 }
@@ -572,6 +575,9 @@ panel_application_plugin_move (GtkWidget        *item,
   panel_return_if_fail (XFCE_IS_PANEL_PLUGIN_PROVIDER (item));
   panel_return_if_fail (PANEL_IS_APPLICATION (application));
 
+  /* keep a reference to prevent any use-after-free when DnDing between different panels */
+  g_object_ref (item);
+
   /* block autohide */
   panel_application_windows_blocked (application, TRUE);
 
@@ -722,7 +728,8 @@ panel_application_plugin_provider_signal (XfcePanelPluginProvider       *provide
           name = g_strdup (xfce_panel_plugin_provider_get_name (provider));
 
           /* destroy the plugin */
-          gtk_widget_destroy (GTK_WIDGET (provider));
+          itembar = gtk_bin_get_child (GTK_BIN (window));
+          gtk_container_remove (GTK_CONTAINER (itembar), GTK_WIDGET (provider));
 
           /* remove the plugin configuration */
           panel_application_plugin_delete_config (application, name, unique_id);
@@ -1506,7 +1513,7 @@ panel_application_new_window (PanelApplication *application,
   /* put the window in its own group */
   window_group = gtk_window_group_new ();
   gtk_window_group_add_window (window_group, GTK_WINDOW (window));
-  g_object_weak_ref (G_OBJECT (window), (GWeakNotify) g_object_unref, window_group);
+  g_object_weak_ref (G_OBJECT (window), _panel_utils_weak_notify, window_group);
 
   /* add the window to internal list */
   application->windows = g_slist_append (application->windows, window);
