@@ -205,15 +205,14 @@ panel_base_window_init (PanelBaseWindow *window)
   window->background_rgba = NULL;
   window->enter_opacity = 1.00;
   window->leave_opacity = 1.00;
-  window->leave_opacity_old = 1.00;
 
   window->priv->css_provider = gtk_css_provider_new ();
   window->priv->borders = PANEL_BORDER_NONE;
   window->priv->active_timeout_id = 0;
 
   screen = gtk_widget_get_screen (GTK_WIDGET (window));
-  g_signal_connect (G_OBJECT (screen), "composited-changed",
-                    G_CALLBACK (panel_base_window_composited_changed), window);
+  g_signal_connect_object (G_OBJECT (screen), "composited-changed",
+                           G_CALLBACK (panel_base_window_composited_changed), window, 0);
 
   /* some wm require stick to show the window on all workspaces, on xfwm4
    * the type-hint already takes care of that */
@@ -523,8 +522,6 @@ panel_base_window_composited_changed (GdkScreen *screen,
 
   if (window->is_composited)
     {
-      if (window->leave_opacity != window->leave_opacity_old)
-        window->leave_opacity = window->leave_opacity_old;
       gtk_widget_set_opacity (GTK_WIDGET (widget), window->leave_opacity);
       panel_base_window_set_plugin_data (window,
                                          panel_base_window_set_plugin_leave_opacity);
@@ -532,11 +529,8 @@ panel_base_window_composited_changed (GdkScreen *screen,
     }
   else
     {
-      /* make sure that the leave opacity is always disabled without compositing, but
-         remember the original value so we can reset it if compositing gets re-enabled */
-      window->leave_opacity_old = window->leave_opacity;
-      window->leave_opacity = 1.0;
-      gtk_widget_set_opacity (GTK_WIDGET (widget), window->leave_opacity);
+      /* make sure to always disable the leave opacity without compositing */
+      gtk_widget_set_opacity (GTK_WIDGET (widget), 1.0);
       panel_base_window_set_plugin_data (window,
                                          panel_base_window_set_plugin_leave_opacity);
     }
@@ -566,15 +560,13 @@ static gboolean
 panel_base_window_active_timeout (gpointer user_data)
 {
   PanelBaseWindow        *window = PANEL_BASE_WINDOW (user_data);
-  GTimeVal                timeval;
   GtkStyleContext        *context;
 
   context = gtk_widget_get_style_context (GTK_WIDGET (window));
 
   /* Animate the border à la "marching ants" by cycling betwee a dashed and
      dotted border every other second */
-  g_get_current_time (&timeval);
-  if (timeval.tv_sec%2 == 0)
+  if ((g_get_real_time () / G_USEC_PER_SEC) % 2 == 0)
     {
       if (gtk_style_context_has_class (context, MARCHING_ANTS_DOTTED))
         gtk_style_context_remove_class (context, MARCHING_ANTS_DOTTED);
@@ -755,7 +747,10 @@ panel_base_window_set_plugin_leave_opacity (GtkWidget *widget,
 {
   PanelBaseWindow *window = PANEL_BASE_WINDOW (user_data);
 
-  panel_base_window_set_plugin_opacity (widget, user_data, window->leave_opacity);
+  if (window->is_composited)
+    panel_base_window_set_plugin_opacity (widget, user_data, window->leave_opacity);
+  else
+    panel_base_window_set_plugin_opacity (widget, user_data, 1.0);
 }
 
 
