@@ -71,23 +71,24 @@ panel_dialogs_show_about (void)
   gchar **authors;
 
   authors = g_new0 (gchar *, 6);
-  authors[0] = g_strdup ("Nick Schermer <nick@xfce.org>");
   authors[1] = g_strdup ("Andrzej Radecki <ndrwrdck@gmail.com>");
-  authors[2] = g_strdup ("Simon Steinbeiß <simon@xfce.org>");
+  authors[1] = g_strdup ("Gaël Bonithon <gael@xfce.org>");
   authors[3] = g_strdup ("Jasper Huijsmans <jasper@xfce.org>");
+  authors[0] = g_strdup ("Nick Schermer <nick@xfce.org>");
+  authors[2] = g_strdup ("Simon Steinbeiß <simon@xfce.org>");
   authors[4] = g_strdup ("Tic-Tac-Toe <tictactoe@xfce.org>");
 
   about_dialog = gtk_about_dialog_new ();
   gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG (about_dialog), (const gchar**) authors);
   g_strfreev (authors);
   gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG (about_dialog), _("The panel of the Xfce Desktop Environment"));
-  gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (about_dialog), "Copyright \302\251 2004-2018 Xfce Development Team");
+  gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (about_dialog), "Copyright \302\251 2004-2022 The Xfce development team");
   gtk_about_dialog_set_license (GTK_ABOUT_DIALOG (about_dialog), XFCE_LICENSE_GPL);
   gtk_about_dialog_set_program_name (GTK_ABOUT_DIALOG (about_dialog), PACKAGE_NAME);
   gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (about_dialog), _("translator-credits"));
   gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (about_dialog), PACKAGE_VERSION);
   gtk_about_dialog_set_website (GTK_ABOUT_DIALOG (about_dialog), "http://www.xfce.org/");
-  gtk_about_dialog_set_logo_icon_name (GTK_ABOUT_DIALOG (about_dialog), PACKAGE_NAME);
+  gtk_about_dialog_set_logo_icon_name (GTK_ABOUT_DIALOG (about_dialog), "org.xfce.panel");
   gtk_window_set_destroy_with_parent (GTK_WINDOW (about_dialog), TRUE);
   g_signal_connect (G_OBJECT (about_dialog), "activate-link",
                     G_CALLBACK (panel_dialogs_show_about_email_hook), NULL);
