@@ -227,7 +227,7 @@ panel_preferences_dialog_init (PanelPreferencesDialog *dialog)
   g_free (path_new);
   connect_signal ("panel-switch", "clicked", panel_preferences_dialog_panel_switch);
 
-  /* style tab */
+  /* appearance tab */
   object = gtk_builder_get_object (GTK_BUILDER (dialog), "background-style");
   panel_return_if_fail (G_IS_OBJECT (object));
   g_signal_connect_swapped (G_OBJECT (object), "changed",
@@ -1471,7 +1471,11 @@ panel_preferences_dialog_item_selection_changed (GtkTreeSelection       *selecti
   panel_return_if_fail (PANEL_IS_PREFERENCES_DIALOG (dialog));
 
   provider = panel_preferences_dialog_item_get_selected (dialog, NULL);
-  if (G_LIKELY (provider != NULL))
+
+  /* when removing an item from the panel, this handler is called when the item is
+   * still selected but has already been unparented, so we also have to check its parent
+   * (see panel_itembar_unref()) */
+  if (G_LIKELY (provider != NULL && gtk_widget_get_parent (GTK_WIDGET (provider)) != NULL))
     {
       /* get the current position and the items on the bar */
       itembar = gtk_bin_get_child (GTK_BIN (dialog->active));
