@@ -1382,12 +1382,19 @@ actions_plugin_default_array (void)
 
 
 static void
-actions_plugin_menu_deactivate (GtkWidget *menu,
-                                GtkWidget *button)
+actions_plugin_menu_deactivate (GtkWidget     *menu,
+                                ActionsPlugin *plugin)
 {
+  GtkWidget *button;
+
+  panel_return_if_fail (XFCE_IS_ACTIONS_PLUGIN (plugin));
+
+  button = gtk_bin_get_child (GTK_BIN (plugin));
   panel_return_if_fail (button == NULL || GTK_IS_TOGGLE_BUTTON (button));
   panel_return_if_fail (GTK_IS_MENU (menu));
 
+  xfce_panel_plugin_block_autohide (XFCE_PANEL_PLUGIN (plugin), FALSE);
+
   /* button is NULL when we popup the menu under the cursor position */
   if (button != NULL)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
@@ -1415,11 +1422,13 @@ actions_plugin_menu (GtkWidget     *button,
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
     return;
 
+  xfce_panel_plugin_block_autohide (XFCE_PANEL_PLUGIN (plugin), TRUE);
+
   if (plugin->menu == NULL)
     {
       plugin->menu = gtk_menu_new ();
       g_signal_connect (G_OBJECT (plugin->menu), "selection-done",
-          G_CALLBACK (actions_plugin_menu_deactivate), button);
+          G_CALLBACK (actions_plugin_menu_deactivate), plugin);
       g_object_add_weak_pointer (G_OBJECT (plugin->menu), (gpointer) &plugin->menu);
 
       allowed_types = actions_plugin_actions_allowed ();
