@@ -1892,7 +1892,8 @@ launcher_plugin_add_desktop_actions (GtkWidget *widget, gpointer user_data)
 static void
 launcher_plugin_button_update_action_menu (LauncherPlugin *plugin)
 {
-  GarconMenuItem      *item = NULL;
+  GarconMenuItem *item = NULL;
+  GList          *list;
 
   panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
   panel_return_if_fail (plugin->menu == NULL);
@@ -1912,9 +1913,11 @@ launcher_plugin_button_update_action_menu (LauncherPlugin *plugin)
   if (plugin->action_menu)
     {
       gtk_widget_destroy (GTK_WIDGET (plugin->action_menu));
+      plugin->action_menu = NULL;
     }
-  else
+  else if (item != NULL && (list = garcon_menu_item_get_actions (item)) != NULL)
     {
+      g_list_free (list);
       plugin->action_menu = GTK_WIDGET (garcon_gtk_menu_get_desktop_actions_menu (item));
       if (plugin->action_menu)
         {
@@ -2001,6 +2004,11 @@ launcher_plugin_button_release_event (GtkWidget      *button,
       || ARROW_INSIDE_BUTTON (plugin))
     return FALSE;
 
+  /* leave if button release happens outside of launcher */
+  if (event->x < 0 || event->x > gdk_window_get_width (event->window) ||
+      event->y < 0 || event->y > gdk_window_get_height (event->window))
+    return FALSE;
+
   /* get the menu item and the screen */
   item = GARCON_MENU_ITEM (plugin->items->data);
   screen = gtk_widget_get_screen (button);
