@@ -428,11 +428,11 @@ sn_item_properties_callback (GObject      *source_object,
   GError *error = NULL;
 
   item->properties_proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
-  g_signal_connect (item->item_proxy, "g-signal",
-                    G_CALLBACK (sn_item_signal_received), item);
   free_error_and_return_if_cancelled (error);
   finish_and_return_if_true (item->properties_proxy == NULL);
 
+  g_signal_connect (item->item_proxy, "g-signal",
+                    G_CALLBACK (sn_item_signal_received), item);
   sn_item_invalidate (item);
 }
 
@@ -698,7 +698,7 @@ sn_item_get_all_properties_result (GObject      *source_object,
   const gchar  *name;
   GVariant     *value;
 
-  const gchar  *cstr_val1;
+  const gchar  *cstr_val1, *item_status = NULL;
   gchar        *str_val1;
   gchar        *str_val2;
   gboolean      bool_val1;
@@ -753,7 +753,7 @@ sn_item_get_all_properties_result (GObject      *source_object,
       }
     else if (!g_strcmp0 (name, "Status"))
       {
-        cstr_val1 = g_variant_get_string (value, NULL);
+        item_status = cstr_val1 = g_variant_get_string (value, NULL);
         bool_val1 = sn_item_status_is_exposed (cstr_val1);
         if (bool_val1 != item->exposed)
           {
@@ -862,28 +862,40 @@ sn_item_get_all_properties_result (GObject      *source_object,
       if (item->id != NULL)
         {
           item->initialized = TRUE;
-          if (item->exposed)
-            g_signal_emit (G_OBJECT (item), sn_item_signals[EXPOSE], 0);
+          update_exposed = TRUE;
+          update_tooltip = FALSE;
+          update_icon = TRUE;
+          update_menu = FALSE;
         }
+      else
+        return;
     }
-  else
-    {
-      if (update_exposed)
-        g_signal_emit (G_OBJECT (item), sn_item_signals[item->exposed ? EXPOSE : SEAL], 0);
 
-      if (item->exposed)
+  if (update_exposed)
+    g_signal_emit (G_OBJECT (item), sn_item_signals[item->exposed ? EXPOSE : SEAL], 0);
+
+  if (item->exposed)
+    {
+      if (update_tooltip)
+        g_signal_emit (G_OBJECT (item), sn_item_signals[TOOLTIP_CHANGED], 0);
+      if (update_icon)
         {
-          if (update_tooltip)
-            g_signal_emit (G_OBJECT (item), sn_item_signals[TOOLTIP_CHANGED], 0);
-          if (update_icon)
-            g_signal_emit (G_OBJECT (item), sn_item_signals[ICON_CHANGED], 0);
-          if (update_menu)
+          /* we prioritize the attention icon if it exists afterwards, but it may
+           * exist here without the corresponding status, which is authentic */
+          if (g_strcmp0 (item_status, "NeedsAttention") != 0)
             {
-              if (item != NULL)
-                g_object_unref (item->cached_menu);
-              item->cached_menu = NULL;
-              g_signal_emit (G_OBJECT (item), sn_item_signals[MENU_CHANGED], 0);
+              g_clear_object (&item->attention_icon_pixbuf);
+              g_free (item->attention_icon_name);
+              item->attention_icon_name = NULL;
             }
+          g_signal_emit (G_OBJECT (item), sn_item_signals[ICON_CHANGED], 0);
+        }
+      if (update_menu)
+        {
+          if (item->cached_menu != NULL)
+            g_object_unref (item->cached_menu);
+          item->cached_menu = NULL;
+          g_signal_emit (G_OBJECT (item), sn_item_signals[MENU_CHANGED], 0);
         }
     }
 }
